@@ -11,7 +11,7 @@ use File::Spec ();
 # Globals
 use vars qw{$VERSION @ISA @EXPORT @EXPORT_OK $IMPLEMENTED_BY};
 BEGIN {
-	$VERSION = '0.87_01';
+	$VERSION = '0.90_01';
 
 	# Inherit manually
 	require Exporter;
@@ -75,6 +75,9 @@ if ( $IMPLEMENTED_BY ) {
 } elsif ( $^O eq 'MacOS' ) {
 	# Legacy Mac OS
 	$IMPLEMENTED_BY = 'File::HomeDir::MacOS9';
+} elsif ( -d '/etc/xdg' ) {
+	# freedesktop unixes
+	$IMPLEMENTED_BY = 'File::HomeDir::FreeDesktop';
 } else {
 	# Default to Unix semantics
 	$IMPLEMENTED_BY = 'File::HomeDir::Unix';
@@ -616,7 +619,7 @@ L<File::ShareDir>, L<File::HomeDir::Win32> (legacy)
 
 =head1 COPYRIGHT
 
-Copyright 2005 - 2009 Adam Kennedy.
+Copyright 2005 - 2010 Adam Kennedy.
 
 Some parts copyright 2000 Sean M. Burke.
 
